package model

import (
	"net/http"
	"time"

	pasturePb "gitee.com/xuyiping_admin/go_proto/proto/go/backend/cow"
	operationPb "gitee.com/xuyiping_admin/go_proto/proto/go/backend/operation"
)

const InitManagerPassword = "123456"

type SystemUser struct {
	Id        int64                  `json:"id"`
	Name      string                 `json:"name"`
	NickName  string                 `json:"nick_name"`
	Mobile    string                 `json:"mobile"`
	Password  string                 `json:"password"`
	Avatar    string                 `json:"avatar"`
	RoleId    int64                  `json:"role_id"`
	DeptId    int64                  `json:"dept_id"`
	Remarks   string                 `json:"remarks"`
	Gender    pasturePb.Genders_Kind `json:"gender"`
	IsShow    pasturePb.IsShow_Kind  `json:"is_show"`
	IsDelete  pasturePb.IsShow_Kind  `json:"is_delete"`
	CreatedAt int64                  `json:"created_at"`
	UpdatedAt int64                  `json:"updated_at"`
}

func (s *SystemUser) TableName() string {
	return "system_user"
}

func (s *SystemUser) SystemUserFormat(userRoles []*SystemRole, pastures []*operationPb.UserPasture) *operationPb.UserAuth {
	roles := make([]*operationPb.UserRole, len(userRoles))
	for k, v := range userRoles {
		roles[k] = &operationPb.UserRole{
			Id:   int32(v.Id),
			Name: v.Name,
		}
	}

	return &operationPb.UserAuth{
		Code: http.StatusOK,
		Msg:  "ok",
		Data: &operationPb.UserAuthData{
			UserName: s.Name,
			Roles:    roles,
			Pastures: pastures,
		},
	}
}

type SystemUserSlice []*SystemUser

func (s SystemUserSlice) ToPB(roleList []*SystemRole) []*operationPb.AddSystemUser {
	res := make([]*operationPb.AddSystemUser, len(s))
	for i, v := range s {
		res[i] = &operationPb.AddSystemUser{
			Id:              int32(v.Id),
			Name:            v.Name,
			CreatedAt:       int32(v.CreatedAt),
			CreatedAtFormat: time.Unix(v.CreatedAt, 0).Format(LayoutTime),
			RoleName:        "",
		}
	}
	return res
}

func (s *SystemUser) ToPb() *operationPb.AddSystemUser {

	return &operationPb.AddSystemUser{
		Id:              int32(s.Id),
		Name:            s.Name,
		CreatedAt:       int32(s.CreatedAt),
		CreatedAtFormat: time.Unix(s.CreatedAt, 0).Format(LayoutTime),
		RoleIds:         []int32{},
	}
}
